CONTENT INSIGHTS SDK INTEGRATION
===========================

Android SDK setup
-----------------------

Provided `ContentInsightsSdk-x.x.x.aar` file copy into `<project_root>/android/app/libs` folder. In case `libs` folder does not exists, create it.


### - build.gradle modification

In order for Gradle to include aar file into generated APK file it is necessary to modify build.gradle file at `<project_root>/android/app/build.gradle`

Under dependencies section in build.gradle file update:

From
- `implementation fileTree(dir: "libs", include: ["*.jar"]) `

To

- `implementation fileTree(dir: "libs", include: ["*.jar", "*.aar"])`

In case above line does not exists, add it.

### - Application code

For creation of Native Android module, please refer to:
https://reactnative.dev/docs/native-modules-android

In order to use ContentInsights SDK, it is required to create Native module which is derived from `ReactContextBaseJavaModule` class. Native module class needs to implement getName method which represents name of the module in ReactNative app.

```java
    /**
     * Get name of the module, to be used in ReactNative as NativeModules.{module_name}
     */
    @Override
    @NonNull
    public String getName() {
        return "ContentInsightsSDKModule";
    }
```

See: ContentInsightsSDKModule.java at `<project_root>/android/app/src/main/java/com.contentinsightssdkintegration`

Created module needs to be included in Package class. It is necessary that created Native Package class implements  `ReactPackage` interface and that created Native module is added to package's module list. For example:
```java   
    /**
     * {@inheritDoc}
     */
    @Override
    @NonNull
    public List<NativeModule> createNativeModules(
            @NonNull ReactApplicationContext reactContext) {
        List<NativeModule> modules = new ArrayList<>();
        modules.add(new ContentInsightsSDKModule(reactContext, domainId));

        return modules;
    }
```

For more information, see ContentInsightsExamplePackage.java at `<project_root>/android/app/src/main/java/com.contentinsightssdkintegration`


Components in ReactNative code can access created Native module in following way: 

```javascript
import {
  NativeModules,
} from 'react-native';


const sdk = NativeModules.ContentInsightsSDKModule;
sdk.startTracker("https://test-domain.com/article/test", "1", {"word_count": 1, "comments_number": 2, "referrer": "test-domain", "authors":[1,2,3,4,5], "published_date": "2020-01-01"});
setTimeout(() => sdk.pauseAttention(), 3000);
setTimeout(() => sdk.startAttention(), 10000);
setTimeout(() => sdk.flushArticles(), 25000);
const onScroll = (e) => {
    sdk.setNewScrollPosition(Math.round(e.nativeEvent.contentOffset.y));
}

```

