
package com.contentinsightssdkintegration;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.contentinsights.sdk.ContentInsights;
import com.contentinsights.sdk.ContentInsightsConfig;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;

/**
 * Class for integration with ContentInsights SDK tracker
 */
public class ContentInsightsSDKModule extends ReactContextBaseJavaModule {


    /**
     * Class constructor
     *
     * @param context Application context
     * @param domainId Domain id for module
     */
    ContentInsightsSDKModule(ReactApplicationContext context, int domainId) {
        super(context);
        ContentInsightsConfig config = new ContentInsightsConfig.Builder(context, domainId)
                .doLogWithTag("ContentInsightsSDK")
                .build();
        ContentInsights.init(config);
    }

    /**
     * Get name of the module, to be used in ReactNative as NativeModules.{module_name}
     */
    @Override
    @NonNull
    public String getName() {
        return "ContentInsightsSDKModule";
    }

    /**
     * Start recording attention time
     */
    @ReactMethod
    public void startAttention() {
        ContentInsights.tracking().startAttention();
    }

    /**
     * Pause attention time recording (e.g. when client minimize app)
     */
    @ReactMethod
    public void pauseAttention() {
        ContentInsights.tracking().pauseAttention();
    }

    /**
     * Set new position of the vertical scroll on article page
     *
     * @param position Position of the scroll
     */
    @ReactMethod
    public void setNewScrollPosition(int position) {
        ContentInsights.tracking().setNewScrollPosition(position);
    }

    /**
     * Flush specific article from the tracking list
     */
    @ReactMethod
    public void flushArticle() {
        ContentInsights.tracking().flushArticle();
    }

    /**
     * Initialize article reads tracker
     *
     * @param articleUrl Url of the article
     * @param articleId Id of the article
     * @param referrerUrl Referrer url
     */
    @ReactMethod
    public void startArticleReadTracker(String articleUrl, String articleId, @Nullable String referrerUrl) {
        ContentInsights.tracking().startArticleReadTracker(articleUrl, articleId, referrerUrl);
    }

    /**
     * Initialize attention time tracker
     *
     * @param articleUrl Url of the article
     * @param articleId Id of the article
     * @param referrerUrl Other article data
     */
    @ReactMethod
    public void startAttentionTracker(
            String articleUrl, String articleId, String referrerUrl
            ) {
        ContentInsights.tracking().startAttentionTracker(articleUrl, articleId, referrerUrl);
    }

}